# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/marisco',
                'doc_host': 'https://franckalbinet.github.io',
                'git_url': 'https://github.com/franckalbinet/marisco',
                'lib_path': 'marisco'},
  'syms': { 'marisco.callbacks': { 'marisco.callbacks.Callback': ('api/callbacks.html#callback', 'marisco/callbacks.py'),
                                   'marisco.callbacks.EncodeTimeCB': ('api/callbacks.html#encodetimecb', 'marisco/callbacks.py'),
                                   'marisco.callbacks.EncodeTimeCB.__call__': ('api/callbacks.html#__call__', 'marisco/callbacks.py'),
                                   'marisco.callbacks.EncodeTimeCB.__init__': ('api/callbacks.html#__init__', 'marisco/callbacks.py'),
                                   'marisco.callbacks.SanitizeLonLatCB': ('api/callbacks.html#sanitizelonlatcb', 'marisco/callbacks.py'),
                                   'marisco.callbacks.SanitizeLonLatCB.__call__': ('api/callbacks.html#__call__', 'marisco/callbacks.py'),
                                   'marisco.callbacks.SanitizeLonLatCB.__init__': ('api/callbacks.html#__init__', 'marisco/callbacks.py'),
                                   'marisco.callbacks.Transformer': ('api/callbacks.html#transformer', 'marisco/callbacks.py'),
                                   'marisco.callbacks.Transformer.__call__': ('api/callbacks.html#__call__', 'marisco/callbacks.py'),
                                   'marisco.callbacks.Transformer.__init__': ('api/callbacks.html#__init__', 'marisco/callbacks.py'),
                                   'marisco.callbacks.Transformer.callback': ('api/callbacks.html#callback', 'marisco/callbacks.py'),
                                   'marisco.callbacks.Transformer.unique': ('api/callbacks.html#unique', 'marisco/callbacks.py'),
                                   'marisco.callbacks.run_cbs': ('api/callbacks.html#run_cbs', 'marisco/callbacks.py')},
            'marisco.cli.create_nc_template': { 'marisco.cli.create_nc_template.main': ( 'cli/create_nc_template.html#main',
                                                                                         'marisco/cli/create_nc_template.py')},
            'marisco.cli.init': {'marisco.cli.init.main': ('cli/init.html#main', 'marisco/cli/init.py')},
            'marisco.cli.netcdfy': { 'marisco.cli.netcdfy.import_handler': ('cli/netcdfy.html#import_handler', 'marisco/cli/netcdfy.py'),
                                     'marisco.cli.netcdfy.main': ('cli/netcdfy.html#main', 'marisco/cli/netcdfy.py')},
            'marisco.configs': { 'marisco.configs.Enums': ('api/configs.html#enums', 'marisco/configs.py'),
                                 'marisco.configs.Enums.__init__': ('api/configs.html#__init__', 'marisco/configs.py'),
                                 'marisco.configs.Enums.filter': ('api/configs.html#filter', 'marisco/configs.py'),
                                 'marisco.configs.Enums.lookup': ('api/configs.html#lookup', 'marisco/configs.py'),
                                 'marisco.configs.base_path': ('api/configs.html#base_path', 'marisco/configs.py'),
                                 'marisco.configs.cache_path': ('api/configs.html#cache_path', 'marisco/configs.py'),
                                 'marisco.configs.cdl_cfg': ('api/configs.html#cdl_cfg', 'marisco/configs.py'),
                                 'marisco.configs.cfg': ('api/configs.html#cfg', 'marisco/configs.py'),
                                 'marisco.configs.get_enum_dicts': ('api/configs.html#get_enum_dicts', 'marisco/configs.py'),
                                 'marisco.configs.get_lut': ('api/configs.html#get_lut', 'marisco/configs.py'),
                                 'marisco.configs.lut_path': ('api/configs.html#lut_path', 'marisco/configs.py'),
                                 'marisco.configs.name2grp': ('api/configs.html#name2grp', 'marisco/configs.py'),
                                 'marisco.configs.nc_tpl_name': ('api/configs.html#nc_tpl_name', 'marisco/configs.py'),
                                 'marisco.configs.nc_tpl_path': ('api/configs.html#nc_tpl_path', 'marisco/configs.py'),
                                 'marisco.configs.nuc_lut_path': ('api/configs.html#nuc_lut_path', 'marisco/configs.py'),
                                 'marisco.configs.sanitize': ('api/configs.html#sanitize', 'marisco/configs.py'),
                                 'marisco.configs.sediments_lut_path': ('api/configs.html#sediments_lut_path', 'marisco/configs.py'),
                                 'marisco.configs.species_lut_path': ('api/configs.html#species_lut_path', 'marisco/configs.py')},
            'marisco.handlers.helcom': { 'marisco.handlers.helcom.LookupBiotaBodyPartCB': ( 'handlers/helcom.html#lookupbiotabodypartcb',
                                                                                            'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupBiotaBodyPartCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                                     'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupBiotaBodyPartCB.__init__': ( 'handlers/helcom.html#__init__',
                                                                                                     'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupBiotaSpeciesCB': ( 'handlers/helcom.html#lookupbiotaspeciescb',
                                                                                           'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupBiotaSpeciesCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                                    'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupBiotaSpeciesCB.__init__': ( 'handlers/helcom.html#__init__',
                                                                                                    'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupSedimentCB': ( 'handlers/helcom.html#lookupsedimentcb',
                                                                                       'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupSedimentCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                                'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LookupSedimentCB.__init__': ( 'handlers/helcom.html#__init__',
                                                                                                'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LowerStripRdnNameCB': ( 'handlers/helcom.html#lowerstriprdnnamecb',
                                                                                          'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.LowerStripRdnNameCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                                   'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.NormalizeUncUnitCB': ( 'handlers/helcom.html#normalizeuncunitcb',
                                                                                         'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.NormalizeUncUnitCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                                  'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.NormalizeUncUnitCB.__init__': ( 'handlers/helcom.html#__init__',
                                                                                                  'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.NormalizeUncUnitCB.fix_units': ( 'handlers/helcom.html#fix_units',
                                                                                                   'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.ParseTimeCB': ( 'handlers/helcom.html#parsetimecb',
                                                                                  'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.ParseTimeCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                           'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.RemapRdnNameCB': ( 'handlers/helcom.html#remaprdnnamecb',
                                                                                     'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.RemapRdnNameCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                              'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.RemapRdnNameCB.__init__': ( 'handlers/helcom.html#__init__',
                                                                                              'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.RenameColumnCB': ( 'handlers/helcom.html#renamecolumncb',
                                                                                     'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.RenameColumnCB.__call__': ( 'handlers/helcom.html#__call__',
                                                                                              'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.RenameColumnCB.__init__': ( 'handlers/helcom.html#__init__',
                                                                                              'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.ReshapeLongToWide': ( 'handlers/helcom.html#reshapelongtowide',
                                                                                        'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.ReshapeLongToWide.__call__': ( 'handlers/helcom.html#__call__',
                                                                                                 'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.ReshapeLongToWide.__init__': ( 'handlers/helcom.html#__init__',
                                                                                                 'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.encode': ('handlers/helcom.html#encode', 'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.fix_units': ( 'handlers/helcom.html#fix_units',
                                                                                'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.get_attrs': ( 'handlers/helcom.html#get_attrs',
                                                                                'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.get_bodypart': ( 'handlers/helcom.html#get_bodypart',
                                                                                   'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.get_maris_species': ( 'handlers/helcom.html#get_maris_species',
                                                                                        'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.get_sediment': ( 'handlers/helcom.html#get_sediment',
                                                                                   'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.get_unique_nuclides': ( 'handlers/helcom.html#get_unique_nuclides',
                                                                                          'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.get_varnames_lut': ( 'handlers/helcom.html#get_varnames_lut',
                                                                                       'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.get_worms_species': ( 'handlers/helcom.html#get_worms_species',
                                                                                        'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.load_data': ( 'handlers/helcom.html#load_data',
                                                                                'marisco/handlers/helcom.py'),
                                         'marisco.handlers.helcom.rename_cols': ( 'handlers/helcom.html#rename_cols',
                                                                                  'marisco/handlers/helcom.py')},
            'marisco.handlers.maris_dump': { 'marisco.handlers.maris_dump.DropNAColumnsCB': ( 'handlers/maris_dump.html#dropnacolumnscb',
                                                                                              'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.DropNAColumnsCB.__call__': ( 'handlers/maris_dump.html#__call__',
                                                                                                       'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.DropNAColumnsCB.__init__': ( 'handlers/maris_dump.html#__init__',
                                                                                                       'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.DropNAColumnsCB.dropMarisNA': ( 'handlers/maris_dump.html#dropmarisna',
                                                                                                          'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.DropNAColumnsCB.isMarisNA': ( 'handlers/maris_dump.html#ismarisna',
                                                                                                        'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.ParseTimeCB': ( 'handlers/maris_dump.html#parsetimecb',
                                                                                          'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.ParseTimeCB.__call__': ( 'handlers/maris_dump.html#__call__',
                                                                                                   'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.RemapRdnNameCB': ( 'handlers/maris_dump.html#remaprdnnamecb',
                                                                                             'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.RemapRdnNameCB.__call__': ( 'handlers/maris_dump.html#__call__',
                                                                                                      'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.RemapRdnNameCB.__init__': ( 'handlers/maris_dump.html#__init__',
                                                                                                      'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.RenameColumnCB': ( 'handlers/maris_dump.html#renamecolumncb',
                                                                                             'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.RenameColumnCB.__call__': ( 'handlers/maris_dump.html#__call__',
                                                                                                      'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.RenameColumnCB.__init__': ( 'handlers/maris_dump.html#__init__',
                                                                                                      'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.ReshapeLongToWide': ( 'handlers/maris_dump.html#reshapelongtowide',
                                                                                                'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.ReshapeLongToWide.__call__': ( 'handlers/maris_dump.html#__call__',
                                                                                                         'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.ReshapeLongToWide.__init__': ( 'handlers/maris_dump.html#__init__',
                                                                                                         'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.ReshapeLongToWide.pivot': ( 'handlers/maris_dump.html#pivot',
                                                                                                      'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.ReshapeLongToWide.renamed_cols': ( 'handlers/maris_dump.html#renamed_cols',
                                                                                                             'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.SanitizeDetectionLimitCB': ( 'handlers/maris_dump.html#sanitizedetectionlimitcb',
                                                                                                       'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.SanitizeDetectionLimitCB.__call__': ( 'handlers/maris_dump.html#__call__',
                                                                                                                'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.SanitizeDetectionLimitCB.__init__': ( 'handlers/maris_dump.html#__init__',
                                                                                                                'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.encode': ( 'handlers/maris_dump.html#encode',
                                                                                     'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.enums_xtra': ( 'handlers/maris_dump.html#enums_xtra',
                                                                                         'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.get_attrs': ( 'handlers/maris_dump.html#get_attrs',
                                                                                        'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.get_dl_lut': ( 'handlers/maris_dump.html#get_dl_lut',
                                                                                         'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.get_fname': ( 'handlers/maris_dump.html#get_fname',
                                                                                        'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.get_varnames_lut': ( 'handlers/maris_dump.html#get_varnames_lut',
                                                                                               'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.get_zotero_key': ( 'handlers/maris_dump.html#get_zotero_key',
                                                                                             'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.load_data': ( 'handlers/maris_dump.html#load_data',
                                                                                        'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.load_dump': ( 'handlers/maris_dump.html#load_dump',
                                                                                        'marisco/handlers/maris_dump.py'),
                                             'marisco.handlers.maris_dump.renaming_rules': ( 'handlers/maris_dump.html#renaming_rules',
                                                                                             'marisco/handlers/maris_dump.py')},
            'marisco.handlers.tepco': { 'marisco.handlers.tepco.FixMissingValuesCB': ( 'handlers/tepco.html#fixmissingvaluescb',
                                                                                       'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.FixMissingValuesCB.__call__': ( 'handlers/tepco.html#__call__',
                                                                                                'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.FixRangeValueStringCB': ( 'handlers/tepco.html#fixrangevaluestringcb',
                                                                                          'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.FixRangeValueStringCB.__call__': ( 'handlers/tepco.html#__call__',
                                                                                                   'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.FixRangeValueStringCB._extract_and_calculate_mean': ( 'handlers/tepco.html#_extract_and_calculate_mean',
                                                                                                                      'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.FixRangeValueStringCB._transform_if_range': ( 'handlers/tepco.html#_transform_if_range',
                                                                                                              'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.ParseTimeCB': ( 'handlers/tepco.html#parsetimecb',
                                                                                'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.ParseTimeCB.__call__': ( 'handlers/tepco.html#__call__',
                                                                                         'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.ParseTimeCB.__init__': ( 'handlers/tepco.html#__init__',
                                                                                         'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RemapRdnNameCB': ( 'handlers/tepco.html#remaprdnnamecb',
                                                                                   'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RemapRdnNameCB.__call__': ( 'handlers/tepco.html#__call__',
                                                                                            'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RemapRdnNameCB.__init__': ( 'handlers/tepco.html#__init__',
                                                                                            'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RemoveJapanaseCharCB': ( 'handlers/tepco.html#removejapanasecharcb',
                                                                                         'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RemoveJapanaseCharCB.__call__': ( 'handlers/tepco.html#__call__',
                                                                                                  'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RemoveJapanaseCharCB._transform_if_about': ( 'handlers/tepco.html#_transform_if_about',
                                                                                                             'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RenameColumnCB': ( 'handlers/tepco.html#renamecolumncb',
                                                                                   'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RenameColumnCB.__call__': ( 'handlers/tepco.html#__call__',
                                                                                            'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.RenameColumnCB.__init__': ( 'handlers/tepco.html#__init__',
                                                                                            'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.SelectColumnsCB': ( 'handlers/tepco.html#selectcolumnscb',
                                                                                    'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.SelectColumnsCB.__call__': ( 'handlers/tepco.html#__call__',
                                                                                             'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.SelectColumnsCB.__init__': ( 'handlers/tepco.html#__init__',
                                                                                             'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.get_attrs': ('handlers/tepco.html#get_attrs', 'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.load_data': ('handlers/tepco.html#load_data', 'marisco/handlers/tepco.py'),
                                        'marisco.handlers.tepco.time_parser': ( 'handlers/tepco.html#time_parser',
                                                                                'marisco/handlers/tepco.py')},
            'marisco.inout': { 'marisco.inout.read_toml': ('api/inout.html#read_toml', 'marisco/inout.py'),
                               'marisco.inout.write_toml': ('api/inout.html#write_toml', 'marisco/inout.py')},
            'marisco.metadata': { 'marisco.metadata.BboxCB': ('api/metadata.html#bboxcb', 'marisco/metadata.py'),
                                  'marisco.metadata.BboxCB.__call__': ('api/metadata.html#__call__', 'marisco/metadata.py'),
                                  'marisco.metadata.DepthRangeCB': ('api/metadata.html#depthrangecb', 'marisco/metadata.py'),
                                  'marisco.metadata.DepthRangeCB.__call__': ('api/metadata.html#__call__', 'marisco/metadata.py'),
                                  'marisco.metadata.DepthRangeCB.__init__': ('api/metadata.html#__init__', 'marisco/metadata.py'),
                                  'marisco.metadata.GlobAttrsFeeder': ('api/metadata.html#globattrsfeeder', 'marisco/metadata.py'),
                                  'marisco.metadata.GlobAttrsFeeder.__call__': ('api/metadata.html#__call__', 'marisco/metadata.py'),
                                  'marisco.metadata.GlobAttrsFeeder.__init__': ('api/metadata.html#__init__', 'marisco/metadata.py'),
                                  'marisco.metadata.GlobAttrsFeeder.callback': ('api/metadata.html#callback', 'marisco/metadata.py'),
                                  'marisco.metadata.KeyValuePairCB': ('api/metadata.html#keyvaluepaircb', 'marisco/metadata.py'),
                                  'marisco.metadata.KeyValuePairCB.__call__': ('api/metadata.html#__call__', 'marisco/metadata.py'),
                                  'marisco.metadata.KeyValuePairCB.__init__': ('api/metadata.html#__init__', 'marisco/metadata.py'),
                                  'marisco.metadata.TimeRangeCB': ('api/metadata.html#timerangecb', 'marisco/metadata.py'),
                                  'marisco.metadata.TimeRangeCB.__call__': ('api/metadata.html#__call__', 'marisco/metadata.py'),
                                  'marisco.metadata.TimeRangeCB.__init__': ('api/metadata.html#__init__', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroCB': ('api/metadata.html#zoterocb', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroCB.__call__': ('api/metadata.html#__call__', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroCB.__init__': ('api/metadata.html#__init__', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem': ('api/metadata.html#zoteroitem', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem.__init__': ('api/metadata.html#__init__', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem.__repr__': ('api/metadata.html#__repr__', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem.creator_name': ('api/metadata.html#creator_name', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem.exist': ('api/metadata.html#exist', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem.getItem': ('api/metadata.html#getitem', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem.summary': ('api/metadata.html#summary', 'marisco/metadata.py'),
                                  'marisco.metadata.ZoteroItem.title': ('api/metadata.html#title', 'marisco/metadata.py')},
            'marisco.nc_template': { 'marisco.nc_template.NCTemplater': ('api/nc_template.html#nctemplater', 'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.__init__': ( 'api/nc_template.html#__init__',
                                                                                   'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.create_analyte_variables': ( 'api/nc_template.html#nctemplater.create_analyte_variables',
                                                                                                   'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.create_default_variables': ( 'api/nc_template.html#nctemplater.create_default_variables',
                                                                                                   'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.create_enum_types': ( 'api/nc_template.html#nctemplater.create_enum_types',
                                                                                            'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.create_group_specific_variables': ( 'api/nc_template.html#nctemplater.create_group_specific_variables',
                                                                                                          'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.create_groups': ( 'api/nc_template.html#nctemplater.create_groups',
                                                                                        'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.create_variable': ( 'api/nc_template.html#nctemplater.create_variable',
                                                                                          'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.create_variables': ( 'api/nc_template.html#nctemplater.create_variables',
                                                                                           'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.derive': ( 'api/nc_template.html#nctemplater.derive',
                                                                                 'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.generate': ( 'api/nc_template.html#nctemplater.generate',
                                                                                   'marisco/nc_template.py'),
                                     'marisco.nc_template.NCTemplater.nuclide_vars': ( 'api/nc_template.html#nctemplater.nuclide_vars',
                                                                                       'marisco/nc_template.py')},
            'marisco.serializers': { 'marisco.serializers.NetCDFEncoder': ('api/serializers.html#netcdfencoder', 'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.__init__': ( 'api/serializers.html#__init__',
                                                                                     'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder._create_and_copy_variable': ( 'api/serializers.html#netcdfencoder._create_and_copy_variable',
                                                                                                      'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.cast_verbose_rf': ( 'api/serializers.html#netcdfencoder.cast_verbose_rf',
                                                                                            'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.copy_dimensions': ( 'api/serializers.html#netcdfencoder.copy_dimensions',
                                                                                            'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.copy_enum_type': ( 'api/serializers.html#netcdfencoder.copy_enum_type',
                                                                                           'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.copy_global_attributes': ( 'api/serializers.html#netcdfencoder.copy_global_attributes',
                                                                                                   'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.copy_variable': ( 'api/serializers.html#netcdfencoder.copy_variable',
                                                                                          'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.copy_variable_attributes': ( 'api/serializers.html#netcdfencoder.copy_variable_attributes',
                                                                                                     'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.copy_variables': ( 'api/serializers.html#netcdfencoder.copy_variables',
                                                                                           'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.encode': ( 'api/serializers.html#netcdfencoder.encode',
                                                                                   'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.process_group': ( 'api/serializers.html#netcdfencoder.process_group',
                                                                                          'marisco/serializers.py'),
                                     'marisco.serializers.NetCDFEncoder.process_groups': ( 'api/serializers.html#netcdfencoder.process_groups',
                                                                                           'marisco/serializers.py')},
            'marisco.utils': { 'marisco.utils.Callback': ('api/utils.html#callback', 'marisco/utils.py'),
                               'marisco.utils.Transformer': ('api/utils.html#transformer', 'marisco/utils.py'),
                               'marisco.utils.Transformer.__call__': ('api/utils.html#__call__', 'marisco/utils.py'),
                               'marisco.utils.Transformer.__init__': ('api/utils.html#__init__', 'marisco/utils.py'),
                               'marisco.utils.Transformer.callback': ('api/utils.html#callback', 'marisco/utils.py'),
                               'marisco.utils.download_file': ('api/utils.html#download_file', 'marisco/utils.py'),
                               'marisco.utils.download_files_in_folder': ('api/utils.html#download_files_in_folder', 'marisco/utils.py'),
                               'marisco.utils.get_bbox': ('api/utils.html#get_bbox', 'marisco/utils.py'),
                               'marisco.utils.has_valid_varname': ('api/utils.html#has_valid_varname', 'marisco/utils.py'),
                               'marisco.utils.match_maris_sediment': ('api/utils.html#match_maris_sediment', 'marisco/utils.py'),
                               'marisco.utils.match_maris_species': ('api/utils.html#match_maris_species', 'marisco/utils.py'),
                               'marisco.utils.match_worms': ('api/utils.html#match_worms', 'marisco/utils.py'),
                               'marisco.utils.run_cbs': ('api/utils.html#run_cbs', 'marisco/utils.py')}}}